import pytest

from cqd.open_xpd_uuid import validate, GuidValidationError


def test_validate_positive():
    validate('XPDFHRTR')


@pytest.mark.parametrize('guid', ('1234567', '123456789'))
def test_validate_invalid_length(guid: str):
    with pytest.raises(GuidValidationError, match=r'`guid` length must be \d+ characters long'):
        validate(guid)


def test_validate_invalid_characters():
    with pytest.raises(GuidValidationError, match=r'`[-*Li]{4}` characters are not allowed to be used in `guid`'):
        validate('-X-X*XLi')



import random

import pytest

from cqd.open_xpd_uuid import generate


@pytest.mark.parametrize(
    'numeric_id, short_code', (
            (1099511627775, 'ZZZZZZZZ'),
            (29, '0000000X'),
    ))
def test_generate(monkeypatch, numeric_id: int, short_code: str):
    def mock_randint(*args, **kwargs):
        return numeric_id

    monkeypatch.setattr(random, "randint", mock_randint)

    assert generate() == short_code



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='open-xpd-uuid',
    version='0.0.1',
    description='A library of common functions used when creating and managing open-xpd-uuid, '
                'a common, globally-unique name space (uuid) for Product Declarations, including HPDs and EPDs, '
                'to help users find all environmental and health information related to a single product.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    maintainer='C-Change Labs',
    maintainer_email='open-source@c-change-labs.com',
    url='https://github.com/cchangelabs/open-xpd-uuid-lib',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    python_requires='>=3.6',
    tests_require=['pytest'],
)
